#
# spec file for package akonadi-runtime
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           akonadi-runtime
Version:        1.13.0
Release:        lp152.5.10
%define rname   akonadi
Summary:        PIM Storage Service
License:        LGPL-2.1+
Group:          System/GUI/KDE
Url:            http://akonadi-project.org
Source:         http://download.kde.org/stable/%{rname}/src/%{rname}-%{version}.tar.bz2
Source1:        baselibs.conf
Source99:       akonadi-runtime-rpmlintrc
# PATCH-FIX-UPSTREAM: Do not leak external payload files (kde#341884)
Patch0:         do-not-leak-old-external-payload-files.diff
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_program_options-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  cmake >= 2.8.8
BuildRequires:  fdupes
BuildRequires:  kde4-filesystem
BuildRequires:  libqt4-devel
BuildRequires:  libxml2
BuildRequires:  libxslt
BuildRequires:  mariadb
BuildRequires:  shared-mime-info
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(post):    shared-mime-info
Requires(postun):  shared-mime-info
Requires:       libakonadiprotocolinternals1 = %{version}
Requires:       libqt4 >= %(rpm -q --queryformat '%%{VERSION}' libqt4)

%description
This package contains the data files of Akonadi, the KDE PIM storage
service.

%package -n libakonadiprotocolinternals-devel
Summary:        PIM Storage Service: Build Environment
Group:          Development/Libraries/X11
Requires:       libakonadiprotocolinternals1 = %{version}
Requires:       libqt4-devel >= %( echo `rpm -q --queryformat '%%{VERSION}' libqt4-devel`)

%description -n libakonadiprotocolinternals-devel
This package contains development files of Akonadi, the KDE PIM storage
service.

%package -n libakonadiprotocolinternals1
Summary:        PIM Storage Service
Group:          System/GUI/KDE
%requires_ge    libqt4

%description -n libakonadiprotocolinternals1
This package contains the data files of Akonadi, the KDE PIM storage
service.

%prep
%setup -q -n %{rname}-%{version}
%patch0 -p1

%build
  %cmake_kde4 -d build -- -DCONFIG_INSTALL_DIR=/etc -DINSTALL_QSQLITE_IN_QT_PREFIX=TRUE -DWITH_SOPRANO=FALSE
  %make_jobs

%install
  %kde4_makeinstall -C build
  %fdupes -s %{buildroot}%{_kde4_includedir}

> files.sqldrivers
if test -d $RPM_BUILD_ROOT%{_kde4_libdir}/qt4/plugins/sqldrivers
then
	# A database access plugin, not a development file
	echo "%{_kde4_libdir}/qt4" >> files.sqldrivers
fi

%post
/sbin/ldconfig
%mime_database_post

%postun
/sbin/ldconfig
%mime_database_postun

%post -n libakonadiprotocolinternals1 -p /sbin/ldconfig

%postun -n libakonadiprotocolinternals1 -p /sbin/ldconfig

%files -f files.sqldrivers
%defattr(-,root,root)
%{_kde4_bindir}/asapcat
%{_kde4_bindir}/akonadi*
%dir %{_kde4_sysconfdir}/akonadi
%config %{_kde4_sysconfdir}/akonadi/mysql-global.conf
%config %{_kde4_sysconfdir}/akonadi/mysql-global-mobile.conf
%{_kde4_datadir}/dbus-1/services/org.freedesktop.Akonadi.Control.service
%{_kde4_datadir}/mime/packages/akonadi-mime.xml

%files -n libakonadiprotocolinternals-devel
%defattr(-,root,root)
%{_kde4_includedir}/akonadi/
%dir %{_kde4_libdir}/cmake
%{_kde4_libdir}/cmake/Akonadi
%{_kde4_datadir}/dbus-1/interfaces/org.freedesktop.Akonadi.*.xml
%{_kde4_libdir}/libakonadiprotocolinternals.so
%{_kde4_libdir}/pkgconfig/akonadi.pc

%files -n libakonadiprotocolinternals1
%defattr(-,root,root)
%{_kde4_libdir}/libakonadiprotocolinternals.so.1*

%changelog
* Thu Dec  7 2017 dimstar@opensuse.org
- Escape the usage of %%{VERSION} when calling out to rpm.
  RPM 4.14 has %%{VERSION} defined as 'the main packages version'.
* Fri Sep  8 2017 fabian@ritter-vogt.de
- Reduce runtime Requires, akonadi-runtime shouldn't be used anymore,
  but just built against
- Needed for libqt4-sql-mysql removal
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Mon Nov 14 2016 wbauer@tmo.at
- Use shared-mime-info macros (boo#979301)
* Tue Jun 30 2015 lbeltrame@kde.org
- Add do-not-leak-old-external-payload-files.diff: do not leak
  external payload files, fixes disk usage of akonadi file_db_data
  (kde#341884)
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashisms in post/postun scripts
* Wed Oct 29 2014 olaf@aepfle.de
- Package sqldrivers depending on its availibility instead of
  a given suse_version number
* Thu Sep 11 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf, needed for kdebase4-workspace-libs-32bit
* Fri Aug 15 2014 tittiatcoke@gmail.com
- Update to 1.13.0
  * Fixed virtual collections statistics
  * Fixed tag RID fetch
  * Fixed HRID-based fetches
  * Fixed race condition in StorageDebugger
  * Use FindBacktrace.cmake from CMake 3.0 instead of our own
    detection
* Thu Jul 10 2014 cgiboudeaux@gmx.com
- Update to 1.12.91
  * MERGE command for faster synchronization
  * Optimizations in various commands handlers
  * SELECT command is obsolete now
  * Performance and concurrency improvements in QSQLITE3 driver
  * Introduced Collection sync preferences as an improvement over the IMAP-based subscription model
  * Disable filesystem copy-on-write for DB files when running on Btrfs
  * Introduced direct streaming of external parts
  * Fixed SearchManager DBus interface not being registered to DBus
  * Fixed handling of tags in AK-APPEND and MERGE commands
  * Various fixes in virtual collections handling
- Drop 0001-Remove-the-invalid-GID-part-from-PartTable-before-st.patch (merged upstream)
* Tue Apr 22 2014 hrvoje.senjan@gmail.com
- Added 0001-Remove-the-invalid-GID-part-from-PartTable-before-st.patch,
  resolves migration problems from earlier akonadi versions, kde#331867
* Tue Apr  8 2014 tittiatcoke@gmail.com
- Update to 1.12.1
  * Bugfix releases. Resolves performance issues with the baloo
    indexer and prevents dataloss when copying large email collections
* Thu Mar 27 2014 tittiatcoke@gmail.com
- Update to 1.12.0
  - KDE 4.13 RC release
  * See http://www.kde.org/announcements/announce-4.13-beta3.php
- Drop upstreamed patch do-not-emit-itemchanged.diff.
* Sun Mar 23 2014 tittiatcoke@gmail.com
- Add upstream patch do-not-emit-itemchanged.diff to prevent
  baloo from constantly indexing the maildir
* Thu Mar 20 2014 tittiatcoke@gmail.com
- Update to 1.11.90
  * KDE 4.13 Beta 3  release
  * See http://www.kde.org/announcements/announce-4.13-beta3.php
- Drop upstreamed patches:
  * janitor-move-parts-as-required-during-check.diff
  * fix-postgresql-query.diff
  * fix-mailrefresh.diff
  * fix-postgresql-2.diff
* Fri Mar 14 2014 tittiatcoke@gmail.com
- Add upstream patch janitor-move-parts-as-required-during-check.diff
  to increase performance of akonadictl fsck
* Wed Mar 12 2014 tittiatcoke@gmail.com
- Add upstream patches fix-postgresql-query.diff,
  fix-postgresql-2.diff to fix the issue when migrating an existing
  PostgreSQL database
- Add upstream patch fix-mailrefresh.diff to fix the issue around
  automatically refreshing emails
* Fri Mar  7 2014 tittiatcoke@gmail.com
- Update to 1.11.80
  * KDE 4.13 Beta 1  release
  * See http://www.kde.org/announcements/announce-4.13-beta1.php
* Sat Feb 15 2014 hrvoje.senjan@gmail.com
- Remove sles checks
- Use kde4 macros
* Fri Nov 29 2013 hrvoje.senjan@gmail.com
- Update to 1.11.0
  * Fixed joined UPDATE queries failing with SQLite
* Sat Nov  9 2013 hrvoje.senjan@gmail.com
- Update to 1.10.80
  * Servser-side notification filtering
  * GID support
  * Export custom agent properties to clients
  * Faster Akonadi shutdown
  * Improved and faster database schema check on start
  * Enabled C++11 support
  * Optimize some SQL queries
  * Store only relative paths to external payload files in database
- Drop gcc41.diff, not required anymore
* Fri Oct  4 2013 hrvoje.senjan@gmail.com
- Update to 1.10.3
  * Fix support for latest PostgreSQL
  * Check MySQL version at runtime, require at least 5.1
  * Fix crash when destroying DataStore with backends other than MySQL
  * Fix problem with too long socket paths
  * Send dummy queries to MySQL to keep the connection alive
  * Fix crash when no flags are changed
  * For more details see:
    http://www.progdan.cz/2013/10/akonadi-1-10-3-with-postgresql-fix/
* Thu Aug  1 2013 coolo@suse.com
- openSUSE defaults to mariadb, so let's do the same
* Thu Jul 25 2013 hrvoje.senjan@gmail.com
- Update to 1.10.2
  * Fix PostgreSQL support (once more)
  * Changes from version 1.10.1:
  * Fix PostgreSQL support
  * Optimize appending flags to items
  * Introduce CHANGEDSINCE parameter to FETCH command
* Tue Jul  9 2013 cgiboudeaux@gmx.com
- Update to 1.10.0
  * Memory optimizations
  * Fix a runtime error on Windows
* Thu Jun 13 2013 hrvoje.senjan@gmail.com
- Update to 1.9.80
  * Update item access time less often.
  * Don't try to start akonadiserver if mysqld is not installed
  * Allow to fetch available items even if there are errors in
    some of the items.
  * Properly restrict the external part removal to the deleted
    collection.
  * Support checking the cache for payloads in the FETCH command.
  * Add infrastructure to track client capabilities.
  * Allow to disable the cache verification on retrieval.
  * fsck: move orphaned pim items to lost+found, delete orphaned
    pim item flags.
  * Introduce NotificationMessageV2 that supports batch operations
    on set of entities.
  * Fix build with Boost >= 1.53.
  * Fix a runtime issue with MySQL >= 5.6 (MySQL >= 5.1.3 is now
    the minimum version).
- Drop mysql56.diff, patch is included in this release
* Fri Jun  7 2013 cgiboudeaux@gmx.com
- Add mysql56.diff
  Renames an option that was removed in MySQL >= 5.6 (kde#319016)
* Mon May  6 2013 hrvoje.senjan@gmail.com
- Update to 1.9.2
  * Add option to FETCH to ignore external retrieval failures.
  * Properly restrict external payload removal.
  * Add buildsystem option to choose between Qt4 and Qt5.
  * Changes from version 1.9.1:
  * Disable query cache for Sqlite.
  * Handle missing mysqld better.
  * Ignore my.cnf settings when using the internal MySQL server.
* Thu Dec 27 2012 hrvoje.senjan@gmail.com
- Update to 1.9.0
  * Respect collection cache policy refresh interval for collection tree sync.
  * Fix initialization of PostgreSQL database.
  * Correctly count items flags in virtual collections.
  * Notify parent virtual collections about item changes.
  * Require CMake >= 2.8.8.
  * Remove dependency to Automoc4.
  * Support Qt 5.
- Remove automoc4 BuildRequires
* Sun Nov 25 2012 cgiboudeaux@gmx.com
- Only require mysql on SLES.
* Sat Nov 24 2012 cgiboudeaux@gmx.com
- Update to 1.9beta1
  * Recover from lost external payload files.
  * Improve the virtual collections handling.
  * Many code and queries optimizations.
* Tue Nov 20 2012 nico.kruber@gmail.com
- Fix the SLES build (%%make_install is not expanded on SLES)
* Fri Nov  2 2012 tittiatcoke@gmail.com
- Update to akonadi 1.8.1
  * Fix payload loss on some move/copy scenarios.
  * Improve error reporting for failed item retrievals.
* Tue Jul 31 2012 toddrme2178@gmail.com
- Update to 1.8.0
  * Fix deadlock in ad-hoc Nepomuk searches.
* Fri Jul 20 2012 toddrme2178@gmail.com
- Update to 1.7.95
  * Fix Nepomuk queries getting stuck if Nepomuk service crashes.
  * Fix unecessary remote retrieval of already cached item parts.
  * Reset RID/RREV during cross-resource collection moves.
  * Increase timeout for remote item retrieval.
- Update to 1.7.90
  * Fix handling of large SPARQL queries.
  * Support cleanup of orphaned resources in the consistency checker.
  * Support compilation with Clang.
- Rebased patch
* Fri Jul  6 2012 dmueller@suse.com
- fix build failure with gcc41
* Wed Apr 18 2012 kruber@zib.de
- Update to 1.7.2
  * Fix and optimize searching via Nepomuk.
* Wed Mar  7 2012 idonmez@suse.com
- Update to 1.7.1
  * Don't truncate SPARQL queries in virtual collections.
  * Optimize change notifications for deleted collection attributes.
  * Fix possible data loss during item copy/move operations.
* Mon Jan 23 2012 hrvoje.senjan@gmail.com
- Update to 1.7.0
  - Fix search result retrieval from Nepomuk.
  - Support for PostgreSQL >= 9.
  - Improve RFC 3501 compatibility in LOGIN and non-silent SELECT commands.
  - Add support for running multiple instance concurrently in the same user session.
  - Update agent interface to include collectionTreeSynchronized signal.
  - Add consistency checker system.
  - Add support for database vacuuming.
  - Various optimizations to reduce the number of SQL queries.
* Mon Jan  2 2012 dmueller@suse.de
- update to 1.6.90 (1.7 RC1):
  - Support for PostgreSQL >= 9.
  - Improve RFC 3501 compatibility in LOGIN and non-silent SELECT commands.
  - Add support for running multiple instance concurrently in the same user session.
  - Update agent interface to include collectionTreeSynchronized signal.
  - Add consistency checker system.
  - Add support for database vacuuming.
  - Various optimizations to reduce the number of SQL queries.
* Wed Oct 19 2011 coolo@suse.com
- switch back to mysql default backend (bnc#718367)
* Fri Oct  7 2011 wstephenson@suse.com
- Update to 1.6.2
  - Do not update item revision if only the RID or RREV changed.
  - Fix usage of wrong ids for part filenames.
  - Only set item dirty flag if the payload changed.
  - Only drop content mimetype for unsubscribed collections in LIST/LSUB.
- 1.6.1 changes:
  - Fix crash on agent launcher exit.
  - Fix valgrind-ing agents running in the agent launcher.
  - Fix restarting of agents in broken state.
  - Fix pipe naming on multi-user Windows systems.
  - Raise MySQL timeout.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Tue Sep 13 2011 idonmez@suse.com
- Fix tarball URL
* Wed Jul 27 2011 idonmez@novell.com
- Use SQLite backend
* Mon Jul 11 2011 cgiboudeaux@gmx.com
- Update to 1.6.0
  - Enable external payload storage unconditionally.
  - Treat single UID/RID fetches as error if the result set is empty.
  - WinCE database performance improvements.
  - Include destination resource in move notifications.
  - Fix crash in protocol parser.
  - Fix possible race on accessing table caches.
  - Use QStringBuilder if available.
  - Improved notification message API.
- Spec cleanup. Remove unneeded build requirements
* Sat May  7 2011 cgiboudeaux@gmx.com
- Update to 1.5.3
  - Don't crash when copying a folder into itself. (BKO#271808)
* Thu Apr  7 2011 cgiboudeaux@gmx.com
- Update to 1.5.2:
  - Fix XdgBaseDirs reporting duplicated paths.
  - Use correct database name when using internal MySQL.
  - Unbreak searching with Nepomuk 4.6.
* Mon Mar 14 2011 freitag@novell.com
- add fix for the nepomuk query api, backport from akonadi 1.5,
  commit be3b9db9
* Thu Feb 17 2011 wstephenson@novell.com
- call update-mime-database in pre/post install scripts
* Sun Jan 30 2011 cgiboudeaux@gmail.com
- Update to 1.5.0
  - Fix Boost related build issues on Windows.
  - Hide akonadi_agent_launcher from Mac OS X dock.
* Fri Jan  7 2011 adrian@suse.de
- Update to 1.4.95
  - Optimize notification compression.
  - Consider ignore flag when calculating collection statistics.
  - Fix item payload size calculation.
  - Improved FETCH response order heuristic.
  - Fix Strigi-based persistent search folders.
  - Fix error propagation in FETCH command handler.
* Mon Dec 20 2010 tittiatcoke@gmail.com
- Update to 1.4.90
  - Set agent status for crashed instances.
  - Allow to restart crashed agent instances.
  - Automatically recover from loss of the resource table.
  - Allow to specify the query language in persistent search commands.
  - Fix leak of notification sources.
* Fri Dec 17 2010 wstephenson@novell.com
- Move modified sqlite driver into main package
* Tue Dec 14 2010 wstephenson@novell.com
- rpmlint fixes:
  * Remove redundant rpmlint override for fixed exit() call in lib
  * Remove obsolete distro versions
* Sun Nov 21 2010 dmueller@suse.de
- update to 1.4.80:
  - Experimental support for MeeGo.
  - Return changed revision numbers in STORE response.
  - Fix Nepomuk searches mixing up items and email attachments.
  - Experimental Strigi search backend.
  - Compensate for Nepomuk D-Bus API breakage.
  - Fix parsing of serialization format version.
  - Optimize collection statistics queries.
  - Optimize protocol output generation.
  - Optimize protocol parsing.
  - Build-time configurable default database backend.
  - Fix ancestor chain quoting.
  - Fix finding of components on Windows in install location.
  - New subscription interface for change notifications.
  - Support for in-process agents and agent server.
  - Support for Sqlite.
  - Experimental support for ODBC-based database backends.
  - Support Windows CE.
* Fri Nov 19 2010 wstephenson@novell.com
- update to 1.4.53 snapshot
* Mon Oct 25 2010 wstephenson@novell.com
- update to 1.4.1:
  * Server startup performance fix
  * IMAP Parser fixes
* Sun Aug 15 2010 wstephenson@novell.com
- update branch diff to r1163872:
  * Improve query performance
  * Resolve spurious 'fatal error' in startup log
  * Use mysqlcheck instead of mysql_upgrade to avoid permission
    lockout
* Mon Aug  2 2010 dmueller@suse.de
- update to 1.4.0:
  * Add change notification for collection subscription state changes.
  * Enable filesystem payload store by default.
  * Fix unicode folder name encoding regression.
* Fri Jul 16 2010 dmueller@suse.de
- update to 1.3.90 (1.4.0 RC1):
  - Reset RIDs on inter-resource moves.
  - Optimize disk space usage with internal MySQL.
  - Improve error reporting of the Akonadi remote debugging server.
  - Fix moving collections into the collection root.
  - Report PostgreSQL database errors in english independent of locale settings.
  - Fix unicode collection name encoding.
  - Optimize cache pruning with filesystem payload store.
  - Fix automatic migration between database and filesystem payload store.
* Tue Jun 15 2010 wstephenson@novell.com
- Add branch diff
  - fix error message on every Akonadi start (bnc#582375)
* Mon Mar  8 2010 wstephenson@suse.de
- tweak mysql behaviour for robustness
* Tue Feb  9 2010 llunak@novell.com
- update to 1.3.1:
  - fix D-Bus connection leak problem
* Wed Jan 20 2010 dmueller@suse.de
- update to 1.3.0:
  - Work around D-Bus bug that could cause SEARCH to hang.
* Wed Jan  6 2010 dmueller@suse.de
- update to 1.2.90:
  - Fix change notifications for search results.
  - Fix database creation with PostgreSQL.
  - Fix copying of item flags.
  - Fix internal MySQL shutdown.
  - Support PostgreSQL in internal mode.
  - Fix table name case mismatch.
* Tue Dec  1 2009 dmueller@suse.de
- update to 1.2.80:
  - Support for collection content type filtering as part of LIST.
  - Adapt to Nepomuk query service changes.
  - Experimental support for PostgreSQL.
  - Support for preprocessor agents.
  - Support for distributed searching.
  - Support for agents creating virtual collections.
  - Protocol parser fixes for non-Linux/non-KDE clients.
  - Support for single-shot searches using the Nepomuk query service.
  - Support HRID-based LIST operations.
  - Support RID-based MOVE, COLMOVE, LINK and UNLINK opertions.
  - Respect cache-only retrieval also regarding on-demand syncing.
  - Add configuration accepted/rejected signals to the agent interface.
  - Fix change notification compression when using modified parts sets.
  - Use one retrieval pipeline per resource.
  - Reduce unecessary change notification on flag changes.
  - Fix RID quoting.
  - Fix resource creating race for autostarted agents.
  - Create new database also when using external db servers.
  - Return the created result collection when creating a persistent search.
* Fri Aug 28 2009 dmueller@suse.de
-update to 1.2.1:
  - Fix item creation with RID's containing a ']'.
  - Fix ASAP parser not reading the entire command.
* Wed Jul 29 2009 dmueller@suse.de
- update to 1.2.0:
  * Fix attribute joining in collection list results.
  - Buildsystem fixes for Mac OS.
  - Do not show a console window for akonadi_control on Windows.
* Tue Jun 23 2009 dmueller@suse.de
- update to 1.1.95 (1.2 RC1):
  * Correctly check if the new cache policy really differs
  from the old one, and only then send a change notification.
* Tue Jun 23 2009 beineri@opensuse.org
- update to svn985593 to meet minimum Akonadi protocol version
* Mon Jun 15 2009 dmueller@suse.de
- update to 1.1.91 svn snapshot
  * small protocol changes
* Wed Jun  3 2009 dmueller@suse.de
- update to 1.1.90:
  * no upstream changelog available
* Mon May 18 2009 dmueller@suse.de
- update to current svn snapshot
* Mon May 18 2009 beineri@opensuse.org
- add 1_2_BRANCH.diff: bump protocol version to 12
* Thu May 14 2009 beineri@opensuse.org
- update to 1.1.85 release:
  * Improved CMake scripts so it is possible to detect
    the Akonadi version in projects that depend on it.
  * Simplified the check for existance of tables.
  * Add a dedicated item deletion command, to get rid of
    the old STORE/EXPUNGE which was extremely inefficient.
  * Some fixes to support sqlite in the future.
  * Soprano is required now.
  * Qt 4.5.0 is required now.
  * Support for collection retrieval by remote identifier.
  * Support for item retrieval based on the remote identifier.
  * Less useless debug output.
  * Fixed leak on socket error.
  * Various smaller bug fixes, see ChangeLog for a list.
  * Support for writing large payloads to a file.
  * New Item retrieval code.
  * Added a streaming IMAP parser, and ported code the use it.
  * Add support for manually restarting an agent instance.
* Wed May 13 2009 dmueller@suse.de
- add versioned dependency
* Thu Apr 30 2009 dmueller@suse.de
- update to 1.1.2:
  * fix dbus loop lockups
* Thu Jan 22 2009 dmueller@suse.de
- update to 1.1.1:
  - Fix code that was not executed in a release build.
  - Require CMake 2.6.0 which fixes boost detection.
  - Don't try to restart an agent that has been deleted.
* Mon Jan 12 2009 dmueller@suse.de
- fix build on SLE10
* Mon Jan  5 2009 dmueller@suse.de
- update to 1.1.0:
  * Restart agents when their executable changed.
  * Buildsystem fixes to find and link boost on all platforms.
  * Improvements to the startup to prevent partial startup.
  * Include revision number in the version string when building from SVN.
  * Shut down when we lost the connection to the D-Bus session bus.
  * add some basic handling of command line args.
  * Add a D-Bus call to flush the notification queue.
  * Automatically fix world-writeable mySQL config files.
  * Fix for FreeBSD mysql path.
* Tue Dec 16 2008 dmueller@suse.de
- update to 1.0.81
* Tue Dec  2 2008 wstephenson@suse.de
- Update to official akonadi 1.80 tarball
- Add external boost dependency
* Mon Sep 29 2008 dmueller@suse.de
- fix build for older distros
* Thu Aug 28 2008 dmueller@suse.de
- require mysql and mysql database adaptor
* Wed Jul 23 2008 dmueller@suse.de
- update to 1.0.0:
  * Bugfix: Unquoted date time with a lenght of
  * 26 characters was not parsed properly.
  * Add serverside timestamp support for items.
  * Build system fixes (windows & automoc)
* Wed Jun 18 2008 dmueller@suse.de
- update to 0.82.0:
  * bugfixes
* Wed May 28 2008 wstephenson@suse.de
- update to 0.82.0pre
  * Protocol change: introduce item part namespaces
* Tue May 20 2008 wstephenson@suse.de
- update to 0.81.0
  * Parsing optimisations
  * Procotol version checks added
  * use external automoc4
* Tue May  6 2008 wstephenson@suse.de
- update to 807704, improve automoc4 location code and IMAP parsing
* Tue May  6 2008 dmueller@suse.de
- update to 804508, dbus interface is under org.freedesktop now
* Fri May  2 2008 dmueller@suse.de
- update to current SVN to adapt API addtions
* Mon Apr 28 2008 dmueller@suse.de
- rename akonadi -> akonadi-runtime
- fix -devel package splitting
- split off library package
* Thu Apr 24 2008 dmueller@suse.de
- Initial package (split out KDE independent parts)
